==> aria2-1.15.2.tar.bz2: aria2-1.15.2/src/XmlRpcDiskWriter.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2012 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "XmlRpcDiskWriter.h"
#include "DlAbortEx.h"
#include "message.h"
#include "ValueBase.h"

namespace aria2 {

namespace rpc {

XmlRpcDiskWriter::XmlRpcDiskWriter()
  : parser_(&psm_)
{}

XmlRpcDiskWriter::~XmlRpcDiskWriter()
{}

void XmlRpcDiskWriter::initAndOpenFile(int64_t totalLength)
{
  parser_.reset();
}
  
void XmlRpcDiskWriter::writeData(const unsigned char* data, size_t len,
                                 int64_t offset)
{
  // Return value is ignored here but handled in finalize()
  parser_.parseUpdate(reinterpret_cast<const char*>(data), len);
}

int XmlRpcDiskWriter::finalize()
{
  return parser_.parseFinal(0, 0);
}

RpcRequest XmlRpcDiskWriter::getResult() const
{
  SharedHandle<List> params;
  if(downcast<List>(psm_.getCurrentFrameValue())) {
    params = static_pointer_cast<List>(psm_.getCurrentFrameValue());
  } else {
    params = List::g();
  }
  return RpcRequest(psm_.getMethodName(), params);
}

int XmlRpcDiskWriter::reset()
{
  return parser_.reset();
}

} // namespace rpc

} // namespace aria2

==> aria2_1.18.1.orig.tar.bz2: aria2-1.18.1/src/XmlRpcDiskWriter.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2012 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "XmlRpcDiskWriter.h"
#include "DlAbortEx.h"
#include "message.h"
#include "ValueBase.h"

namespace aria2 {

namespace rpc {

XmlRpcDiskWriter::XmlRpcDiskWriter()
  : parser_(&psm_)
{}

XmlRpcDiskWriter::~XmlRpcDiskWriter()
{}

void XmlRpcDiskWriter::initAndOpenFile(int64_t totalLength)
{
  parser_.reset();
}

void XmlRpcDiskWriter::writeData(const unsigned char* data, size_t len,
                                 int64_t offset)
{
  // Return value is ignored here but handled in finalize()
  parser_.parseUpdate(reinterpret_cast<const char*>(data), len);
}

int XmlRpcDiskWriter::finalize()
{
  return parser_.parseFinal(nullptr, 0);
}

RpcRequest XmlRpcDiskWriter::getResult()
{
  std::unique_ptr<List> params;
  if(downcast<List>(psm_.getCurrentFrameValue())) {
    params.reset(static_cast<List*>(psm_.popCurrentFrameValue().release()));
  } else {
    params = List::g();
  }
  return RpcRequest{psm_.getMethodName(), std::move(params)};
}

int XmlRpcDiskWriter::reset()
{
  return parser_.reset();
}

} // namespace rpc

} // namespace aria2
